##  Key Features
Use the following features to discover and manage your AI agents.
Features for Discovering and Managing AI Agents Feature | Description | Detailed Information
---|---|---
AI agent extension to the meta model | This extension to the meta model provides a set of dedicated attributes and fact sheet subtypes that enable you to model and govern your organization's AI agents and MCP servers to track the adoption of your AI agent strategy. | [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.")
AI agent discovery |  Create a comprehensive inventory of your AI agents and MCP servers in SAP LeanIX.
  * Upload AI agents using the API or set up integrations with Microsoft Entra ID, Google Agent Engine, and SAP.
  * Discover MCP servers registered in Microsoft Azure API Center.

![Integration options for AI agent discovery in SAP LeanIX, showing various configuration cards.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio02e34a99f6b8410ab88cb1e121e882c9_LowRes.png) AI Agent Discovery | [AI Agent Discovery](https://help.sap.com/docs/leanix/ea/ai-agent-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Discover AI agents and MCP servers by setting up integrations with agent-building platforms and registry systems. Review discovered items in the AI agent discovery inbox and add relevant ones to your inventory.")
AI agent discovery inbox |  Review the discovered items and link them to existing fact sheets or create new ones. You get recommendations for linking relevant fact sheets from your inventory. ![AI Agent Discovery Inbox in SAP LeanIX showing discovered agents and integration details.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio20a37ad3308e49298ef02aab596859bd_LowRes.png) AI Agent Discovery Inbox | [AI Agent Discovery Inbox](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD "AI agents and MCP servers discovered across your enterprise landscape appear in the AI agent discovery inbox. Learn how to review, link, and reject fact sheets related to discovered items.")
AI agent hub dashboard |  Monitor key metrics and get quick access to the AI agent discovery inbox, reports, and other items. ![AI Agent Hub dashboard showing key metrics, discovery inbox, and agent inventory.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe29c7146bc0344769a92d57f5f94a74c_LowRes.png) AI Agent Hub Dashboard | [AI Agent Hub Dashboard](https://help.sap.com/docs/leanix/ea/ai-agent-hub-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "Use the AI agent hub dashboard to get an overview of AI agent data in your workspace.")
Reports for AI agents |  Visualize your AI agent inventory in reports to understand dependencies and drive informed decisions. ![AI Agent Landscape report showing categorized AI agents by business capability and approval state.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiobcbfe47d687f4a82ae6b7eee333ee1f4_LowRes.png) AI Agent Landscape Report | [Reports for AI Agents](https://help.sap.com/docs/leanix/ea/reports-for-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD "Use reports to get an overview of AI agents in your enterprise architecture landscape.")
SAP suggestions |  Activate an optional extension to view SAP suggestions for AI agents and applications in reports. Create fact sheets from relevant suggestions. ![Applications with AI Agents report showing SAP suggestions with a drop-down menu selection for AI agents and applications.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9137b59d0b1d4194beb118442d35feba_LowRes.png) Applications with AI Agents Report Showing SAP Suggestions | [SAP Suggestions in Reports](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports?locale=en-US&state=PRODUCTION&version=CLOUD "View SAP suggestions for AI agents and applications in reports. Create fact sheets from relevant suggestions.")
Calculation templates for AI agents |  Automatically calculate the business value of AI agents. ![AI Agent Business Value Summary showing cost savings, revenue increase, and risk reduction values.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio105fa840126347c384e2a74bf73736fb_LowRes.png) Calculated Fields on an AI Agent Fact Sheet with Example Values | [Calculations for AI Agents](https://help.sap.com/docs/leanix/ea/calculations-for-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically calculate the business value of your AI agents.")
AI agent portal |  Create a dedicated portal for AI agents to help users identify which agents are available. Users can request new agents from the portal. SAP LeanIX doesn't provide a preconfigured portal for AI agents. However, you can create one by adjusting the portal settings for AI agent fact sheets. | [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD "Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.")


